Rdocumentation
powered by
Learn R Programming
psborrow (version 0.2.3)
.priorClass-class: S4 Class for specifying prior distributions and predictors for MCMC methods
Description
S4 Class for specifying prior distributions and predictors for MCMC methods
Arguments